#!/usr/bin/env python

'''
standards.py: lists of standard things to be used with validators

'''

from som.logman import bot

# Sources (lists) of valid identifiers
person_sources = ['stanford']
item_sources = ['pacs']
